@@ -1,6 +1,6 @@
 package DBIx::Custom;
 
-our $VERSION = '0.1685';
+our $VERSION = '0.1686';
 
 use 5.008001;
 use strict;
@@ -171,6 +171,20 @@ sub assign_param {
     return $tag;
 }
 
+sub col {
+    my ($self, $table, $columns) = @_;
+    
+    # Reserved word quote
+    my $q = $self->reserved_word_quote;
+    
+    # Column clause
+    my @column;
+    $columns ||= [];
+    push @column, "$q$table$q.$q$_$q as $q${table}.$_$q" for @$columns;
+    
+    return join (', ', @column);
+}
+
 sub column {
     my ($self, $table, $columns) = @_;
     
@@ -180,7 +194,7 @@ sub column {
     # Column clause
     my @column;
     $columns ||= [];
-    push @column, "$q$table$q.$q$_$q as $q${table}${q}__$q$_$q" for @$columns;
+    push @column, "$q$table$q.$q$_$q as $q${table}__$_$q" for @$columns;
     
     return join (', ', @column);
 }
@@ -274,10 +288,20 @@ sub dbh {
             croak "connector must have dbh() method " . _subname
               unless ref $connector && $connector->can('dbh');
               
-            return $self->{dbh} = $connector->dbh;
+            $self->{dbh} = $connector->dbh;
         }
         
-        return $self->{dbh} ||= $self->_connect;
+        # Connect
+        $self->{dbh} ||= $self->_connect;
+        
+        # Quote
+        unless ($self->reserved_word_quote) {
+            my $driver = $self->{dbh}->{Driver}->{Name};
+            my $quote = $driver eq 'mysql' ? '`' : '"';
+            $self->reserved_word_quote($quote);
+        }
+
+        return $self->{dbh};
     }
 }
 
@@ -772,8 +796,8 @@ sub new {
           unless $self->can($attr);
     }
     
-    # Register tag
-    $self->register_tag(
+    # DEPRECATED!
+    $self->query_builder->{tags} = {
         '?'     => \&DBIx::Custom::Tag::placeholder,
         '='     => \&DBIx::Custom::Tag::equal,
         '<>'    => \&DBIx::Custom::Tag::not_equal,
@@ -785,7 +809,7 @@ sub new {
         'in'    => \&DBIx::Custom::Tag::in,
         'insert_param' => \&DBIx::Custom::Tag::insert_param,
         'update_param' => \&DBIx::Custom::Tag::update_param
-    );
+    };
     
     return $self;
 }
@@ -849,11 +873,21 @@ sub select {
     my @sql;
     push @sql, 'select';
     
+    # Reserved word quote
+    my $q = $self->reserved_word_quote;
+    
     # Column clause
     if ($columns) {
         $columns = [$columns] unless ref $columns eq 'ARRAY';
         foreach my $column (@$columns) {
-            $column = $self->column(%$column) if ref $column eq 'HASH';
+            if (ref $column eq 'HASH') {
+                $column = $self->col(%$column) if ref $column eq 'HASH';
+            }
+            elsif (ref $column eq 'ARRAY') {
+                croak "Format must be [COLUMN, as => ALIAS] " . _subname
+                  unless @$column == 3 && $column->[1] eq 'as';
+                $column = join(' ', $column->[0], 'as', $q . $column->[2] . $q);
+            }
             unshift @$tables, @{$self->_search_tables($column)};
             push @sql, ($column, ',');
         }
@@ -863,7 +897,6 @@ sub select {
     
     # Table
     push @sql, 'from';
-    my $q = $self->reserved_word_quote;
     if ($relation) {
         my $found = {};
         foreach my $table (@$tables) {
@@ -1611,8 +1644,7 @@ L<DBIx::Custom> is L<DBI> wrapper module.
 There are many basic methods to execute various queries.
 C<insert()>, C<update()>, C<update_all()>,C<delete()>,
 C<delete_all()>, C<select()>,
-C<insert_at()>, C<update_at()>, 
-C<delete_at()>, C<select_at()>, C<execute()>
+C<execute()>
 
 =item *
 
@@ -1815,6 +1847,24 @@ Create assign tag.
 
 This is equal to C<update_param> exept that set is not added.
 
+=head2 C<col> EXPERIMETNAL
+
+    my $column = $model->col(book => ['author', 'title']);
+
+Create column clause. The follwoing column clause is created.
+
+    book.author as "book.author",
+    book.title as "book.title"
+
+=head2 C<column> EXPERIMETNAL
+
+    my $column = $dbi->column(book => ['author', 'title']);
+
+Create column clause. The follwoing column clause is created.
+
+    book.author as book__author,
+    book.title as book__title
+
 =head2 C<connect>
 
     my $dbi = DBIx::Custom->connect(
@@ -2346,13 +2396,23 @@ You can specify hash reference. This is EXPERIMENTAL.
         {book => [qw/author title/]},
         {person => [qw/name age/]}
     ]);
-    
-This is expanded to the following one by C<column> method automatically.
 
-    book.author as book__author,
-    book.title as book__title,
-    person.name as person__name,
-    person.age as person__age
+This is expanded to the following one by C<col> method automatically.
+
+    book.author as "book.author",
+    book.title as "book.title",
+    person.name as "person.name",
+    person.age as "person.age"
+
+You can specify array reference in array refernce.
+
+    $dbi->select(column => [
+        ['date(book.register_datetime)', as => 'book.register_date']
+    ]);
+
+These is joined and quoted.
+
+    date(book.register_datetime) as "book.register_date"
 
 =item C<where>
 
