@@ -85,6 +85,23 @@ sub column {
     return $self->dbi->column($table, $columns);
 }
 
+sub col {
+    my ($self, $table, $columns) = @_;
+    
+    $self->{_table_alias} ||= {};
+    my $dist;
+    $dist = $self->dbi->{_table_alias}{$table}
+          ? $self->dbi->{_table_alias}{$table}
+          : $table;
+    
+    $self->dbi->{_model_from} ||= {};
+    my $model = $self->dbi->{_model_from}->{$dist};
+    
+    $columns ||= $self->model($model)->columns;
+    
+    return $self->dbi->col($table, $columns);
+}
+
 sub DESTROY { }
 
 sub method {
@@ -215,8 +232,8 @@ and implements the following new ones.
 
 =head2 C<column> EXPERIMETNAL
 
-    my $column = $self->column(book => ['author', 'title']);
-    my $column = $self->column('book');
+    my $column = $model->column(book => ['author', 'title']);
+    my $column = $model->column('book');
 
 Create column clause. The follwoing column clause is created.
 
@@ -225,6 +242,18 @@ Create column clause. The follwoing column clause is created.
 
 If column names is omitted, C<columns> attribute of the model is used.
 
+=head2 C<col> EXPERIMETNAL
+
+    my $column = $model->col(book => ['author', 'title']);
+    my $column = $model->col('book');
+
+Create column clause. The follwoing column clause is created.
+
+    book.author as "book.author",
+    book.title as "book.title"
+
+If column names is omitted, C<columns> attribute of the model is used.
+
 =head2 C<delete>
 
     $table->delete(...);
@@ -239,13 +268,6 @@ you don't have to specify C<table> option.
 Same as C<delete_all()> of L<DBIx::Custom> except that
 you don't have to specify C<table> option.
 
-=head2 C<delete_at>
-
-    $table->delete_at(...);
-    
-Same as C<delete()> of L<DBIx::Custom> except that
-you don't have to specify C<table> and C<primary_key> option.
-
 =head2 C<insert>
 
     $table->insert(...);
@@ -253,13 +275,6 @@ you don't have to specify C<table> and C<primary_key> option.
 Same as C<insert()> of L<DBIx::Custom> except that
 you don't have to specify C<table> option.
 
-=head2 C<insert>
-
-    $table->insert_at(...);
-    
-Same as C<insert_at()> of L<DBIx::Custom> except that
-you don't have to specify C<table> and C<primary_key> option.
-
 =head2 C<method>
 
     $model->method(
@@ -306,13 +321,6 @@ Create a L<DBIx::Custom::Table> object.
 Same as C<select()> of L<DBIx::Custom> except that
 you don't have to specify C<table> option.
 
-=head2 C<select_at>
-
-    $table->select_at(...);
-    
-Same as C<select_at()> of L<DBIx::Custom> except that
-you don't have to specify C<table> and C<primary_key> option.
-
 =head2 C<update>
 
     $table->update(...);
@@ -327,9 +335,30 @@ you don't have to specify C<table> option.
 Same as C<update_all()> of L<DBIx::Custom> except that
 you don't have to specify table name.
 
-=head2 C<update_at>
+=head2 C<update_at> DEPRECATED!
 
     $table->update_at(...);
     
 Same as C<update_at()> of L<DBIx::Custom> except that
 you don't have to specify C<table> and C<primary_key> option.
+
+=head2 C<select_at> DEPRECATED!
+
+    $table->select_at(...);
+    
+Same as C<select_at()> of L<DBIx::Custom> except that
+you don't have to specify C<table> and C<primary_key> option.
+
+=head2 C<insert_at> DEPRECATED!
+
+    $table->insert_at(...);
+    
+Same as C<insert_at()> of L<DBIx::Custom> except that
+you don't have to specify C<table> and C<primary_key> option.
+
+=head2 C<delete_at> DEPRECATED!
+
+    $table->delete_at(...);
+    
+Same as C<delete()> of L<DBIx::Custom> except that
+you don't have to specify C<table> and C<primary_key> option.
